@@ -2,14 +2,14 @@ package IO::Compress::Adapter::Lzma ;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 
-use IO::Compress::Base::Common  2.063 qw(:Status);
+use IO::Compress::Base::Common  2.064 qw(:Status);
 
-use Compress::Raw::Lzma  2.063 qw(LZMA_OK LZMA_STREAM_END) ;
+use Compress::Raw::Lzma  2.064 qw(LZMA_OK LZMA_STREAM_END) ;
 
-our ($VERSION);
-$VERSION = '2.063';
+use vars qw($VERSION);
+$VERSION = '2.064';
 
 sub mkCompObject
 {
