@@ -2,19 +2,19 @@ package IO::Compress::Lzma ;
 
 use strict ;
 use warnings;
-use bytes;
+# use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.063 ;
+use IO::Compress::Base 2.064 ;
 
-use IO::Compress::Base::Common  2.063 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzma 2.063 ;
+use IO::Compress::Base::Common  2.064 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzma 2.064 ;
 
 
 
-our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzmaError);
+use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $LzmaError);
 
-$VERSION = '2.063';
+$VERSION = '2.064';
 $LzmaError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -765,7 +765,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2013 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2014 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
