@@ -2,18 +2,18 @@ package IO::Compress::Xz ;
 
 use strict ;
 use warnings;
-use bytes;
+# use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.063 ;
-use IO::Compress::Base::Common  2.063 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Xz 2.063 ;
-use Compress::Raw::Lzma  2.063 ;
+use IO::Compress::Base 2.064 ;
+use IO::Compress::Base::Common  2.064 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Xz 2.064 ;
+use Compress::Raw::Lzma  2.064 ;
 
 
-our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
+use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $XzError);
 
-$VERSION = '2.063';
+$VERSION = '2.064';
 $XzError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -793,7 +793,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2013 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2014 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
