@@ -2,14 +2,14 @@ package IO::Uncompress::Adapter::UnXz;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 
-use IO::Compress::Base::Common 2.062 qw(:Status);
+use IO::Compress::Base::Common 2.064 qw(:Status);
 
-use Compress::Raw::Lzma 2.062 ;
+use Compress::Raw::Lzma 2.064 ;
 
-our ($VERSION, @ISA);
-$VERSION = '2.062';
+use vars qw($VERSION @ISA);
+$VERSION = '2.064';
 
 #@ISA = qw( Compress::Raw::UnLzma );
 
