@@ -2,17 +2,17 @@ package IO::Uncompress::UnXz ;
 
 use strict ;
 use warnings;
-use bytes;
+# use bytes;
 
-use IO::Compress::Base::Common 2.063 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.064 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.063 ;
-use IO::Uncompress::Adapter::UnXz 2.063 ;
+use IO::Uncompress::Base 2.064 ;
+use IO::Uncompress::Adapter::UnXz 2.064 ;
 
 require Exporter ;
-our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnXzError);
+use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $UnXzError);
 
-$VERSION = '2.063';
+$VERSION = '2.064';
 $UnXzError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -918,7 +918,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2013 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2014 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
